==> haskell-xml-conduit-1.3.4-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xml-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.4
id: xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
key: xmlco_9sVW08AA1QQKoCjNxnJCrX
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
hs-libraries: HSxml-conduit-1.3.4-9sVW08AA1QQKoCjNxnJCrX
depends:
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.3.4-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xml-conduit/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.4
id: xml-conduit-1.3.4-233ad2c214e14cf140bab4070afaa144
key: xmlco_6FtvMlbWlNYCw4292ieBev
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
hs-libraries: HSxml-conduit-1.3.4-6FtvMlbWlNYCw4292ieBev
depends:
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
